# Benu

[![build](https://github.com/strawlab/benu/workflows/build-and-test/badge.svg?branch=master)](https://github.com/strawlab/benu/actions?query=branch%3Amaster)
[![PyPI version](https://badge.fury.io/py/benu.svg)](https://badge.fury.io/py/benu)

Context based transformed plotting tool
